/*
 * Copyright 2014 Kevin Funk <kfunk@kde.org>
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License as
 * published by the Free Software Foundation; either version 2 of
 * the License or (at your option) version 3 or any later version
 * accepted by the membership of KDE e.V. (or its successor approved
 * by the membership of KDE e.V.), which shall act as a proxy
 * defined in Section 14 of version 3 of the license.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 *
 */

#ifndef TESTSTRINGHANDLER_H
#define TESTSTRINGHANDLER_H

#include <QObject>

class TestStringHandler : public QObject
{
    Q_OBJECT

private Q_SLOTS:
    void testHtmlToPlainText();
    void testHtmlToPlainText_data();

    void testFindAsciiIdentifierLength();
    void testFindAsciiIdentifierLength_data();
    void testFindAsciiIdentifierLengthNoMatch();
    void testFindAsciiIdentifierLengthNoMatch_data();

    void testMatchUnbracedAsciiVariable();
    void testMatchUnbracedAsciiVariable_data();
    void testUnmatchedAsciiVariable();
    void testUnmatchedAsciiVariable_data();
    void testMatchBracedAsciiVariable();
    void testMatchBracedAsciiVariable_data();

    void testStripAnsiSequences();
    void testStripAnsiSequences_data();

    void testNormalizeLineEndings();
    void testNormalizeLineEndings_data();
};

#endif // TESTSTRINGHANDLER_H
